VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CLogFile"
Attribute VB_Creatable = True
Attribute VB_Exposed = True
' ======================================================================
' Copyright (C) 1996, Patrick J. Cuff Jr.
'
' This library is free software; you can redistribute it and/or
' modify it under the terms of the GNU Library General Public
' License as published by the Free Software Foundation; either
' version 2 of the License, or any later version.
'
' This library is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
' Library General Public License for more details.
'
' You should have received a copy of the GNU Library General Public
' License along with this library; if not, write to the
' Free Software Foundation, Inc., 59 Temple Place - Suite 330, Cambridge,
' MA 02139, USA.
' ======================================================================
' CLogFile.CLS -- Log File Class.
' ----------------------------------------------------------------------
' This class contains the properties and methods for implementing a log
' file or audit trail in your Visual Basic project.
' ----------------------------------------------------------------------
' Dependencies:
' This file depends directly on the following files:
'   CLogFileConst.BAS -- Log File Constants
' ----------------------------------------------------------------------
' Properties:
'   Name         Type      Description
'   ------------ --------- ---------------------------------------------
'   AppName      String    Name of the application being logged.
'   Message      String    Text to place in the log file.
'   Name         String    Fully qualified path and file name of the log file.
'   Severity     Integer   Classification of the event being logged.
'   Status       Integer   Current status of the log file.
' ----------------------------------------------------------------------
' Methods:
'   Name         Description
'   ------------ -------------------------------------------------------
'   LogEntry     Write an entry to the log file.
'   LogStart     Open the log file.  Append to the log if the file already exists.
'   LogStop      Close the log file.
' ======================================================================
' Revision History:
'    Date     Programmer                Description
' ----------  ------------------------  --------------------------------
' 12-02-1996  Patrick J. Cuff Jr.       Original program logic
' ======================================================================
Option Explicit

' ----------------------------------------------------------------------
' Class Constants
' ----------------------------------------------------------------------

' ----------------------------------------------------------------------
' Public Members
' ----------------------------------------------------------------------

' ----------------------------------------------------------------------
' Private Members
' ----------------------------------------------------------------------
Private hFile           As Integer  ' Handle to the open file.
Private iStatus         As Integer  ' Status of the Log file:  0 = Closed, 1 = Open.
Private iSeverity       As Integer  ' Severity of log entry (see LogFileConst.bas for allowable values).
Private sMessage        As String   ' Log entry.
Private sAppName        As String   ' Name of the application that's running at time of log entry.
Private sName           As String   ' Fully qualified path and file name of the log file.
' ======================================================================
' Sub:
'   LogEntry
'
' Description:
'   This sub will format the Log File properties and write them out to
'   the file.
'
' Revision History:
'    Date     Programmer                Description
' ----------  ------------------------  --------------------------------
' 12-02-1996  Patrick J. Cuff Jr.       Original program logic
' ======================================================================
Sub LogEntry()
Attribute LogEntry.VB_Description = "Write an entry to the log file."
On Error GoTo LogEntry_Err

    Dim rc As Long                  ' Return Code from Win32 API functions.
    Dim sEntry As String            ' Log entry written to file.
    Dim lSize As Long               ' Length of output returned in lpBuffer.
    Dim lpBuffer As String * 255    ' String buffer to hold output for Win32 API functions.
    
    ' If the log file is open, format the output.
    If iStatus = clfOPEN Then
        ' Timestamp the log entry.
        sEntry = Str$(Now)
        
        ' Add the name of the application.
        If sAppName = "" Then
            ' continue
        Else
            sEntry = sEntry & vbTab & Trim$(AppName)
        End If
        
        ' Add the name of the active user.
        lSize = 255
        rc = GetUserName(lpBuffer, lSize)
        If rc = 1 Then
            ' NOTE:  Decrement lSize, since GetUserName includes the NULL terminator as part of the return value.
            sEntry = sEntry & vbTab & Mid$(lpBuffer, 1, lSize - 1)
        End If
        
        ' Add the name of the active workstation.
        lSize = 255
        rc = GetComputerName(lpBuffer, lSize)
        If rc = 1 Then
            ' NOTE:  Do not decrement lSize, since GetComputerName does not include the NULL terminator as part of the return value.
            sEntry = sEntry & vbTab & Mid$(lpBuffer, 1, lSize)
        End If
        
        ' Add the severity.
        sEntry = sEntry & vbTab & Str$(iSeverity)
        
        ' Add the message.
        If Message = "" Then
            ' continue
        Else
            sEntry = sEntry & vbTab & ">> " & Trim$(sMessage)
        End If
        
        ' Write the formatted string out to the file.
        Print #hFile, sEntry
    Else    ' Can't write to a closed file.
        On Error GoTo 0         ' Turn off error handling.
        Err.Raise Number:=(clfERR_LOGFILE_CLOSED + vbObjectError) _
                , Source:=clfSVR_SOURCENAME _
                , Description:=LoadResString(clfERR_LOGFILE_CLOSED)
        GoTo LogEntry_Exit
    End If
    
LogEntry_Exit:
    Exit Sub

LogEntry_Err:
    Dim lErr As Long            ' Error Number
    Dim sErrDesc As String      ' Error Description
    
    ' Save the error number and description.
    lErr = Err.Number
    sErrDesc = Err.Description
    
    ' Throw a general failure error.
    Err.Raise Number:=(clfERR_GENERAL_FAILURE + vbObjectError) _
            , Source:=clfSVR_SOURCENAME _
            , Description:=LoadResString(clfERR_GENERAL_FAILURE) _
            & vbCrLf & Str$(lErr) & "-" & sErrDesc
            
    ' Return to caller.
    GoTo LogEntry_Exit
    
End Sub
Public Property Get Severity() As Integer
Attribute Severity.VB_Description = "Classification of the event being logged:   Informational, Debug, Warning, Error, Critical."
    Severity = iSeverity
End Property
Public Property Get Status() As Integer
Attribute Status.VB_Description = "Current status of the log file:  Open or Closed."
    Status = iStatus
End Property
Public Property Let Severity(ByVal Value As Integer)
    ' If we're passed an invalid value, return an error.
    If Value < clfINFORMATIONAL _
    Or Value > clfCRITICAL Then  ' Error
        Err.Raise Number:=(clfERR_SEVERITY_INVALID + vbObjectError) _
                , Source:=clfSVR_SOURCENAME _
                , Description:=LoadResString(clfERR_SEVERITY_INVALID)
    Else
        iSeverity = Value
    End If
        
End Property
' ======================================================================
' Sub:
'   LogStop
'
' Description:
'   This sub will close the log file.
'
' Revision History:
'    Date     Programmer                Description
' ----------  ------------------------  --------------------------------
' 12-02-1996  Patrick J. Cuff Jr.       Original program logic
' ======================================================================
Sub LogStop()
Attribute LogStop.VB_Description = "Close the log file."
On Error GoTo LogStop_Err

    ' Close the log file.
    If iStatus = clfOPEN Then
        Close hFile
        iStatus = clfCLOSED       ' Mark the log file closed.
        hFile = 0                   ' Re-initialize the file handle (just to be safe).
    Else    ' Can't close a closed file.
        On Error GoTo 0         ' Turn off error handling.
        
        Err.Raise Number:=(clfERR_LOGFILE_CLOSED + vbObjectError) _
                , Source:=clfSVR_SOURCENAME _
                , Description:=LoadResString(clfERR_LOGFILE_CLOSED)
        GoTo LogStop_Exit
    End If

LogStop_Exit:
    Exit Sub
    
LogStop_Err:
    Dim lErr As Long            ' Error Number
    Dim sErrDesc As String      ' Error Description
    
    ' Save the error number and description.
    lErr = Err.Number
    sErrDesc = Err.Description
    
    ' Throw a general failure error.
    Err.Raise Number:=(clfERR_GENERAL_FAILURE + vbObjectError) _
            , Source:=clfSVR_SOURCENAME _
            , Description:=LoadResString(clfERR_GENERAL_FAILURE) _
            & vbCrLf & Str$(lErr) & "-" & sErrDesc
            
    ' Return to caller.
    GoTo LogStop_Exit
    
End Sub
' ======================================================================
' Sub:
'   LogStart
'
' Description:
'   This sub will open the log file.
'
' Revision History:
'    Date     Programmer                Description
' ----------  ------------------------  --------------------------------
' 12-02-1996  Patrick J. Cuff Jr.       Original program logic
' ======================================================================
Sub LogStart()
Attribute LogStart.VB_Description = "Open the log file.  Append to the log if the file already exists."
On Error GoTo LogStart_Err
    Dim sHeader As String     ' Column Header string.
    
    ' We must have a file name or we can't begin.
    If sName = "" Then
        On Error GoTo 0         ' Turn off error handling.
        
        Err.Raise Number:=(clfERR_LOGFILE_NAME_REQUIRED + vbObjectError) _
                , Source:=clfSVR_SOURCENAME _
                , Description:=LoadResString(clfERR_LOGFILE_NAME_REQUIRED)
        GoTo LogStart_Exit
    End If
    
    ' If the file is closed, open it.
    If iStatus = clfCLOSED Then
        hFile = FreeFile        ' Get the next available file handle.
        iStatus = clfOPEN     ' Set the log file status to open.
    
        If FileExists(sName) Then
            ' File exists, append to it.
            Open sName For Append As hFile
        Else
            ' File does not exist, create new.
            Open sName For Output As hFile
            
            ' Create a header in the first row.
            sHeader = sHeader _
                      & "Time" & vbTab _
                      & "Application" & vbTab _
                      & "User" & vbTab _
                      & "Computer" & vbTab _
                      & "Severity" & vbTab _
                      & "Description"
            Print #hFile, sHeader
            
        End If
    Else    ' Can't start an open log.
        On Error GoTo 0         ' Turn off error handling.
        
        Err.Raise Number:=(clfERR_LOGFILE_OPEN + vbObjectError) _
                , Source:=clfSVR_SOURCENAME _
                , Description:=LoadResString(clfERR_LOGFILE_OPEN)
        GoTo LogStart_Exit
    End If
    
LogStart_Exit:
    Exit Sub
    
LogStart_Err:
    Dim lErr As Long            ' Error Number
    Dim sErrDesc As String      ' Error Description
    
    ' Save the error number and description.
    lErr = Err.Number
    sErrDesc = Err.Description
    
    ' Throw a general failure error.
    Err.Raise Number:=(clfERR_GENERAL_FAILURE + vbObjectError) _
            , Source:=clfSVR_SOURCENAME _
            , Description:=LoadResString(clfERR_GENERAL_FAILURE) _
            & vbCrLf & Str$(lErr) & "-" & sErrDesc
            
    ' Return to caller.
    GoTo LogStart_Exit
    
End Sub
' ======================================================================
' Sub:
'   Class_Initialize
'
' Description:
'   This sub will initialize the Log File class, setting defaults where
'   appropriate.
'
' Revision History:
'    Date     Programmer                Description
' ----------  ------------------------  --------------------------------
' 12-02-1996  Patrick J. Cuff Jr.       Original program logic
' ======================================================================
Private Sub Class_Initialize()
    ' Set defaults.
    hFile = 0                       ' Initialize file handle (just to be safe).
    iStatus = clfCLOSED           ' Log file not opened.
    iSeverity = clfINFORMATIONAL  ' Unless specified, all entries are Informational.
End Sub
' ======================================================================
' Sub:
'   Class_Terminate
'
' Description:
'   This sub will shutdown the Log File class, closing the log file if
'   necessary.
'
' Revision History:
'    Date     Programmer                Description
' ----------  ------------------------  --------------------------------
' 12-02-1996  Patrick J. Cuff Jr.       Original program logic
' ======================================================================
Private Sub Class_Terminate()
    ' Close the file, if opened.
    If iStatus = clfOPEN Then
        Close hFile
    End If
End Sub
Public Property Get Message() As String
Attribute Message.VB_Description = "Text to place in the log file."
    Message = sMessage
End Property
Public Property Let Message(ByVal Value As String)
    sMessage = Value
End Property
Public Property Get Name() As String
Attribute Name.VB_Description = "Fully qualified path and filename for the log file."
    Name = sName
End Property
Public Property Let Name(ByVal Value As String)
    sName = Value
End Property
Public Property Get AppName() As String
Attribute AppName.VB_Description = "Name of the Application being logged."
    AppName = sAppName
End Property
Public Property Let AppName(ByVal Value As String)
    sAppName = Value
End Property
